summary refs log tree commit diff stats
path: root/ranger.py
diff options
context:
space:
mode:
Diffstat (limited to 'ranger.py')
-rwxr-xr-xranger.py6
1 files changed, 4 insertions, 2 deletions
diff --git a/ranger.py b/ranger.py
index 090789c5..7ab00a26 100755
--- a/ranger.py
+++ b/ranger.py
@@ -1,6 +1,6 @@
 #!/usr/bin/python
 # coding=utf-8
 # ranger: Browse your files inside the console.
 
 
 # An embedded shell script. Assuming this file is /usr/bin/ranger,
@@ -13,11 +13,13 @@
 if [ $1 ]; then
 	cd "`$1 --cd-after-exit $@ 3>&1 1>&2 2>&3 3>&-`"
 else
-	echo "use with: source path/to/ranger.py path/to/ranger.py"
+	echo "usage: source path/to/ranger.py path/to/ranger.py"
 fi
 return 1
 """
 
+__doc__ = """Ranger - file browser for the unix terminal"""
+
 try:
 	from ranger.main import main
@@ -1,6 +1,6 @@
 #!/usr/bin/python
 # coding=utf-8
-# ranger: Browse your files inside the console.
+# ranger: Browse your files inside the terminal.
 
 